@@ -11,7 +11,7 @@ Use Siphon to query the NetCDF Subset Service (NCSS) and plot on a map.
 This example uses Siphon's NCSS class to provide temperature data
 for contouring a basic map using CartoPy.
 """
-from datetime import datetime
+from datetime import datetime, timezone
 
 import cartopy.crs as ccrs
 import cartopy.feature as cfeature
@@ -49,13 +49,13 @@ query = ncss.query()
 # will return all surface temperatures for points in our bounding box for a single time,
 # nearest to that requested. Note the string representation of the query is a properly encoded
 # query string.
-query.lonlat_box(north=43, south=35, east=-100, west=-111).time(datetime.utcnow())
+query.lonlat_box(north=43, south=35, east=-100, west=-111).time(datetime.now(timezone.utc))
 query.accept('netcdf4')
 query.variables('Temperature_surface')
 
 ###########################################
 # We now request data from the server using this query. The `NCSS` class handles parsing
-# this NetCDF data (using the `netCDF4` module). If we print out the variable names, we see
+# this NetCDF data (using the ``netCDF4`` module). If we print out the variable names, we see
 # our requested variable, as well as the coordinate variables (needed to properly reference
 # the data).
 data = ncss.get_data(query)
@@ -70,8 +70,8 @@ temp_var = data.variables['Temperature_surface']
 # coordinates attribute on temperature
 time_name = temp_var.coordinates.split()[1]
 time_var = data.variables[time_name]
-lat_var = data.variables['lat']
-lon_var = data.variables['lon']
+lat_var = data.variables['latitude']
+lon_var = data.variables['longitude']
 
 ###########################################
 # Now we make our data suitable for plotting.
@@ -111,7 +111,7 @@ cf = ax.contourf(lon_2d, lat_2d, temp_vals, 200, transform=ccrs.PlateCarree(), z
 plt.colorbar(cf, ax=ax, fraction=0.032)
 
 # Make a title with the time value
-ax.set_title(u'Temperature forecast (\u00b0F) for {0:%d %B %Y %H:%MZ}'.format(time_val),
+ax.set_title(f'Temperature forecast (\u00b0F) for {time_val: %d %B %Y %H%MZ}',
              fontsize=20)
 
 # Plot markers for each lat/long to show grid points for 0.25 deg GFS
